#ifndef SURFACE_LIST_H
#define SURFACE_LIST_H

/*!
  \file
  \brief T[tFXXg

  \author Satofumi KAMIMURA

  $Id$
*/

#include "Surface.h"
#include <SDL.h>
#include <vector>
#include <list>


namespace beego {
  /*!
    \brief `T[tFX̊Ǘ
  */
  class DrawSurface {
    static int serial_id;

  public:
    bool mustDraw;		//!< `悷Kv̗L
    SDL_Rect position;		//!< ʒu
    SDL_Rect area;		//!< ItZbgATCY
    Surface surface;		//!< T[tFX
    bool position_changed;	//!< zuύXꂽ
    bool is_changed;
    bool is_transparent;
    std::vector<SDL_Rect> redraw_rects; //!< ĕ`̈
  };

  /*!
    \brief `T[tFXXg
  */
  typedef std::list<DrawSurface*> SurfaceList;
};

#endif /* !SURFACE_LIST_H */
